@@ -5,9 +5,9 @@
 #include <fstream>
 #include <sys/types.h>
 
-#include "input/ReaderBackend.h"
+#include "zeek/input/ReaderBackend.h"
 
-namespace input { namespace reader {
+namespace zeek::input::reader::detail {
 
 /**
  * Binary mode file reader.
@@ -30,19 +30,24 @@ protected:
 private:
 	bool OpenInput();
 	bool CloseInput();
-	streamsize GetChunk(char** chunk);
+	std::streamsize GetChunk(char** chunk);
 	int UpdateModificationTime();
 
-	string fname;
-	ifstream* in;
+	std::string fname;
+	std::ifstream* in;
 	time_t mtime;
 	ino_t ino;
 	bool firstrun;
 
 	// options set from the script-level.
-	static streamsize chunk_size;
-	string path_prefix;
+	static std::streamsize chunk_size;
+	std::string path_prefix;
 };
 
-}
-}
+} // namespace zeek::input::reader::detail
+
+namespace input::reader {
+
+using Binary [[deprecated("Remove in v4.1. Use zeek::input::reader::detail::Binary.")]] = zeek::input::reader::detail::Binary;
+
+} // namespace input::reader
